@@ -1,4 +1,4 @@
-package Pcore::Redis v0.6.1;
+package Pcore::Redis v0.6.2;
 
 use Pcore -dist, -class;
 
@@ -121,10 +121,10 @@ Pcore::Redis
     docker create --name redis -v redis:/var/local/pcore-redis/data/ -p 6379:6379/tcp softvisio/redis
 
     # connect via TCP
-    my $h = Pcore::Handle->new('redis://password@host:port?db=dbindex');
+    my $h = P->handle('redis://password@host:port?db=dbindex');
 
     # connect via unix socket
-    my $h = Pcore::Handle->new('redis://password@/tmp/redis.sock?db=dbindex');
+    my $h = P->handle('redis://password@/tmp/redis.sock?db=dbindex');
 
 =head1 DESCRIPTION
 
